![logo](https://i.imgur.com/AexZWB6.png)
![PyPI-Downloads](https://img.shields.io/pypi/dd/statisfy?style=for-the-badge)
![PyPI-License](https://img.shields.io/pypi/l/statisfy?style=for-the-badge)
&nbsp;
### Get statistics from all of your favourite social media sites, games and more!
&nbsp;
## Install 
```
$ python3 -m pip install -U statisfy
```
&nbsp;

## Problems or issues?

If you encounter any problems, bugs or other issues with the package, please create an [issue in the GitHub repo](https://github.com/aspekts/statisfynpm/issues). 

&nbsp;
## Contact
If you have any questions or just want to reach me, you can get in touch with me on my [Discord server](https://discord.gg/GxGTHBC).